==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/StandardRoleEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.StandardRoleEmbeddedTargets;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Optional embedded resources for the Role Assignment
 */
@ApiModel(description = "Optional embedded resources for the Role Assignment")
@JsonPropertyOrder({ StandardRoleEmbedded.JSON_PROPERTY_TARGETS })
@JsonTypeName("StandardRole__embedded")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class StandardRoleEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TARGETS = "targets";
    private StandardRoleEmbeddedTargets targets;

    public StandardRoleEmbedded() {
    }

    public StandardRoleEmbedded targets(StandardRoleEmbeddedTargets targets) {

        this.targets = targets;
        return this;
    }

    /**
     * Get targets
     *
     * @return targets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public StandardRoleEmbeddedTargets getTargets() {
        return targets;
    }

    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTargets(StandardRoleEmbeddedTargets targets) {
        this.targets = targets;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        StandardRoleEmbedded standardRoleEmbedded = (StandardRoleEmbedded) o;
        return Objects.equals(this.targets, standardRoleEmbedded.targets);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(targets);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class StandardRoleEmbedded {\n");
        sb.append("    targets: ").append(toIndentedString(targets)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/StandardRoleEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.StandardRoleEmbeddedTargets;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Optional embedded resources for the Role Assignment
 */
@ApiModel(description = "Optional embedded resources for the Role Assignment")
@JsonPropertyOrder({ StandardRoleEmbedded.JSON_PROPERTY_TARGETS })
@JsonTypeName("StandardRole__embedded")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class StandardRoleEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TARGETS = "targets";
    private StandardRoleEmbeddedTargets targets;

    public StandardRoleEmbedded() {
    }

    public StandardRoleEmbedded targets(StandardRoleEmbeddedTargets targets) {

        this.targets = targets;
        return this;
    }

    /**
     * Get targets
     *
     * @return targets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public StandardRoleEmbeddedTargets getTargets() {
        return targets;
    }

    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTargets(StandardRoleEmbeddedTargets targets) {
        this.targets = targets;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        StandardRoleEmbedded standardRoleEmbedded = (StandardRoleEmbedded) o;
        return Objects.equals(this.targets, standardRoleEmbedded.targets);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(targets);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class StandardRoleEmbedded {\n");
        sb.append("    targets: ").append(toIndentedString(targets)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
